@@ -54,6 +54,7 @@ use Unicode::UTF8 qw(encode_utf8);
 
 use Debian::Debhelper::Buildsystem::Haskell::Recipes qw(
   run
+  init_hs_env
   make_setup_recipe
   configure_recipe
   build_recipe
@@ -90,41 +91,11 @@ sub new {
 
     $self->enforce_in_source_building;
 
+    init_hs_env();
+
     # set a dummy HOME variable; Cabal expects one
     $ENV{HOME} = '/homedoesnotexistatbuildtime';
 
-    $ENV{DEB_DEFAULT_COMPILER} //= 'ghc';
-
-    $ENV{DEB_GHC_DATABASE} = 'debian/tmp-db';
-
-    my @cabal_candidates = glob('*.cabal');
-
-    error('No cabal file found')
-      unless @cabal_candidates;
-
-    error('More than one cabal file')
-      if @cabal_candidates > 1;
-
-    my $cabal_path = $cabal_candidates[0];
-    my $cabal_contents = path($cabal_path)->slurp_utf8;
-
-    error('Cannot get package name from cabal file')
-      unless $cabal_contents =~ /^ name \s* : \s* (\S*) \s* $/imx;
-
-    my $package_name = lc $1;
-
-    $ENV{CABAL_PACKAGE} //= $package_name;
-
-    error('Cannot get package version from cabal file')
-      unless $cabal_contents =~ /^ version \s* : \s* (\S*) \s* $/imx;
-
-    my $package_version = $1;
-
-    $ENV{CABAL_VERSION} = $package_version;
-
-    $ENV{DEB_ENABLE_TESTS} //= 'no';
-    $ENV{DEB_ENABLE_HOOGLE} //= 'yes';
-
     $ENV{"DEB_DH_GENCONTROL_ARGS_libghc-$ENV{CABAL_PACKAGE}-dev"}
       .= $SPACE . '-- -DGHC-Package=\${haskell:ghc-package}';
 
@@ -150,8 +121,6 @@ sub new {
     # packages are empty. Disables them.
     $ENV{DEB_DH_STRIP_ARGS} .= $SPACE . '--no-automatic-dbgsym';
 
-    $ENV{DEB_SETUP_BIN_NAME} //= 'debian/hlibrary.setup';
-
     # you probably do not need to touch these
     $ENV{GHC6_VERSION} = qx{ghc --numeric-version};
     $ENV{GHC_VERSION} = qx{ghc --numeric-version};
@@ -190,7 +159,9 @@ sub build {
     my ($self) = @_;
 
     build_recipe();
-    haddock_recipe();
+    if (!$dh{DOARCH}) {
+        haddock_recipe();
+    }
     check_recipe();
 
     return;
